@@ -1,14 +1,13 @@
-
-import requests
 import xml.etree.ElementTree as et
 
 import inforion.ln.xml_helper as xhelper
+import requests
+
 
 def execute_soap_request(url, token, request_body):
-    headers = {'content-type': 'text/xml',
-                'Authorization': 'Bearer '+token}
+    headers = {"content-type": "text/xml", "Authorization": "Bearer " + token}
 
-    response = requests.post(url,data=request_body,headers=headers)
+    response = requests.post(url, data=request_body, headers=headers)
     return response
 
 
@@ -29,14 +28,14 @@ def get_base_request_xml(company, service_name):
 
 
 def get_method_xml(service_name, method_name):
-    if method_name == 'List':
+    if method_name == "List":
         return f"""<List xmlns="http://www.infor.com/businessinterface/{service_name}">
                         <ListRequest></ListRequest>
                     </List>"""
-    
+
 
 def get_list_request_xml(company, service_name):
-    method_name = 'List'
+    method_name = "List"
     xml = get_base_request_xml(company, method_name)
     method_xml = get_method_xml(service_name, method_name)
-    return xml.replace('[[body]]', method_xml)
\ No newline at end of file
+    return xml.replace("[[body]]", method_xml)
